---
title: <span class="badge builder"></span> LibraryElementDTOMeta
---
# <span class="badge builder"></span> LibraryElementDTOMeta

## Constructor

```python
LibraryElementDTOMeta()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> librarypanel.LibraryElementDTOMeta
```

### <span class="badge object-method"></span> connected_dashboards

```python
def connected_dashboards(connected_dashboards: int) -> typing.Self
```

### <span class="badge object-method"></span> created

```python
def created(created: str) -> typing.Self
```

### <span class="badge object-method"></span> created_by

```python
def created_by(created_by: cogbuilder.Builder[librarypanel.LibraryElementDTOMetaUser]) -> typing.Self
```

### <span class="badge object-method"></span> folder_name

```python
def folder_name(folder_name: str) -> typing.Self
```

### <span class="badge object-method"></span> folder_uid

```python
def folder_uid(folder_uid: str) -> typing.Self
```

### <span class="badge object-method"></span> updated

```python
def updated(updated: str) -> typing.Self
```

### <span class="badge object-method"></span> updated_by

```python
def updated_by(updated_by: cogbuilder.Builder[librarypanel.LibraryElementDTOMetaUser]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [LibraryElementDTOMeta](./object-LibraryElementDTOMeta.md)
